@@ -91,17 +91,13 @@ class LoadTradeKline(LoadData):
     def __init__(self, *args, **kwargs):
         super(LoadTradeKline, self).__init__(*args, **kwargs)
         self.csv_writer = csv.DictWriter(open(self.csv_path, mode="w"), delimiter=",",
-                                         fieldnames=["symbol", "id", "timestamp", "type", "side", "price", "amount"])
+                                         fieldnames=["symbol", "id", "timestamp", "side", "price", "amount"])
         self.csv_writer.writeheader()
-        # self.table = TradeData(prefix=self.exchange.name,
-        #                       suffix=datetime.utcfromtimestamp(self.unix_start / 1000).strftime('%Y%m%d'))
 
     def load_close(self):
-        # self.table.to_csv_all(file_path=self.csv_path)
         pass
 
     def _write(self, data_list):
-        # self.table.insert(values=data_list)
         self.csv_writer.writerows(data_list)
 
     def load(self, symbol, pbr, *args, **kwargs):
@@ -126,8 +122,7 @@ class LoadTradeKline(LoadData):
                 result = [{
                     'symbol': trade['symbol'],
                     'id': trade['id'].replace('\n', ''),
-                    'timestamp': trade['timestamp'],
-                    'type': trade['type'],
+                    'timestamp': trade['timestamp'] - self.unix_start,
                     'side': trade['side'],
                     'price': trade['price'],
                     'amount': trade['amount'],
